pub struct TransactionBatchProcessor<FG: ForkGraph> {
pub slot: Slot,
pub epoch: Epoch,
pub sysvar_cache: RwLock<SysvarCache>,
pub epoch_boundary_preparation: Arc<RwLock<EpochBoundaryPreparation>>,
pub global_program_cache: Arc<RwLock<ProgramCache<FG>>>,
pub program_runtime_environment: ProgramRuntimeEnvironment,
pub builtin_program_ids: RwLock<HashSet<Pubkey>>,
/* private fields */
}Fields
slot: SlotBank slot (i.e. block)
epoch: EpochBank epoch
sysvar_cache: RwLock<SysvarCache>SysvarCache is a collection of system variables that are accessible from on chain programs. It is passed to SVM from client code (e.g. Bank) and forwarded to process_message.
epoch_boundary_preparation: Arc<RwLock<EpochBoundaryPreparation>>Anticipates the environments of the upcoming epoch
global_program_cache: Arc<RwLock<ProgramCache<FG>>>Programs required for transaction batch processing
program_runtime_environment: ProgramRuntimeEnvironmentProgramRuntimeEnvironment of the current epoch
builtin_program_ids: RwLock<HashSet<Pubkey>>Builtin program ids
Implementations
Sourceimpl<FG: ForkGraph> TransactionBatchProcessor<FG>
impl<FG: ForkGraph> TransactionBatchProcessor<FG>
Sourcepub fn new_uninitialized(slot: Slot, epoch: Epoch) -> Self
pub fn new_uninitialized(slot: Slot, epoch: Epoch) -> Self
Create a new, uninitialized TransactionBatchProcessor.
In this context, uninitialized means that the TransactionBatchProcessor
has been initialized with an empty program cache. The cache contains no
programs (including builtins) and has not been configured with a valid
fork graph.
When using this method, it’s advisable to call set_fork_graph_in_program_cache
as well as add_builtin to configure the cache before using the processor.
Sourcepub fn new(
slot: Slot,
epoch: Epoch,
fork_graph: Weak<RwLock<FG>>,
program_runtime_environment: Option<ProgramRuntimeEnvironment>,
) -> Self
pub fn new( slot: Slot, epoch: Epoch, fork_graph: Weak<RwLock<FG>>, program_runtime_environment: Option<ProgramRuntimeEnvironment>, ) -> Self
Create a new TransactionBatchProcessor.
The created processor’s program cache is initialized with the provided fork graph and loaders. If any loaders are omitted, a default “empty” loader (no syscalls) will be used.
The cache will still not contain any builtin programs. It’s advisable to
call add_builtin to add the required builtins before using the processor.
Sourcepub fn new_from(&self, slot: Slot, epoch: Epoch) -> Self
pub fn new_from(&self, slot: Slot, epoch: Epoch) -> Self
Create a new TransactionBatchProcessor from the current instance, but
with the provided slot and epoch.
- Inherits the program cache and builtin program ids from the current instance.
- Resets the sysvar cache.
Sourcepub fn set_execution_cost(&mut self, cost: SVMTransactionExecutionCost)
pub fn set_execution_cost(&mut self, cost: SVMTransactionExecutionCost)
Sets the base execution cost for the transactions that this instance of transaction processor will execute.
Sourcepub fn set_program_runtime_environment(
&mut self,
new_environment: ProgramRuntimeEnvironment,
)
pub fn set_program_runtime_environment( &mut self, new_environment: ProgramRuntimeEnvironment, )
Updates the environments when entering a new Epoch.
Sourcepub fn program_runtime_environment_for_epoch(
&self,
epoch: Epoch,
) -> ProgramRuntimeEnvironment
pub fn program_runtime_environment_for_epoch( &self, epoch: Epoch, ) -> ProgramRuntimeEnvironment
Returns the current environments depending on the given epoch Returns None if the call could result in a deadlock
pub fn sysvar_cache(&self) -> RwLockReadGuard<'_, SysvarCache>
Sourcepub fn load_and_execute_sanitized_transactions<CB: TransactionProcessingCallback + InvokeContextCallback>(
&self,
callbacks: &CB,
sanitized_txs: &[impl SVMTransaction],
check_results: Vec<TransactionCheckResult>,
environment: &TransactionProcessingEnvironment,
config: &TransactionProcessingConfig<'_>,
) -> LoadAndExecuteSanitizedTransactionsOutput
pub fn load_and_execute_sanitized_transactions<CB: TransactionProcessingCallback + InvokeContextCallback>( &self, callbacks: &CB, sanitized_txs: &[impl SVMTransaction], check_results: Vec<TransactionCheckResult>, environment: &TransactionProcessingEnvironment, config: &TransactionProcessingConfig<'_>, ) -> LoadAndExecuteSanitizedTransactionsOutput
Main entrypoint to the SVM.
pub fn replenish_program_cache<CB: TransactionProcessingCallback>( &self, account_loader: &AccountLoader<'_, CB>, missing_programs: Vec<ProgramToLoad<'_>>, program_runtime_environment_for_execution: &ProgramRuntimeEnvironment, program_cache_for_tx_batch: &mut ProgramCacheForTxBatch, execute_timings: &mut ExecuteTimings, limit_to_load_programs: bool, increment_usage_counter: bool, )
Sourcepub fn prepare_one_program_for_upcoming_feature_set<CB: TransactionProcessingCallback>(
&self,
account_loader: &CB,
check_program_deployment_slot: bool,
upcoming_environment: &ProgramRuntimeEnvironment,
key: &Pubkey,
stats_of_enqueued_program: &ProgramStatistics,
)
pub fn prepare_one_program_for_upcoming_feature_set<CB: TransactionProcessingCallback>( &self, account_loader: &CB, check_program_deployment_slot: bool, upcoming_environment: &ProgramRuntimeEnvironment, key: &Pubkey, stats_of_enqueued_program: &ProgramStatistics, )
Similar to replenish_program_cache() but only used in Bank::prepare_program_cache_for_upcoming_feature_set().
pub fn fill_missing_sysvar_cache_entries<CB: TransactionProcessingCallback>( &self, callbacks: &CB, )
pub fn reset_and_fill_sysvar_cache_entries<CB: TransactionProcessingCallback>( &self, callbacks: &CB, )
pub fn reset_sysvar_cache(&self)
pub fn get_sysvar_cache_for_tests(&self) -> SysvarCache
Sourcepub fn add_builtin(&self, program_id: Pubkey, builtin: ProgramCacheEntry)
pub fn add_builtin(&self, program_id: Pubkey, builtin: ProgramCacheEntry)
Add a built-in program
pub fn writable_sysvar_cache(&self) -> &RwLock<SysvarCache>