pub fn load_program_with_pubkey<CB: TransactionProcessingCallback>(
callbacks: &CB,
program_runtime_environment: &ProgramRuntimeEnvironment,
pubkey: &Pubkey,
current_slot: Slot,
execute_timings: &mut ExecuteTimings,
) -> Option<(Arc<ProgramCacheEntry>, Slot)>Expand description
Loads the program with the given pubkey.
If the account doesn’t exist it returns None. If the account does exist, it must be a program
account (belong to one of the program loaders). Returns Some(InvalidAccountData) if the program
account is Closed, contains invalid data or any of the programdata accounts are invalid.